IQ.Pilot Prebuilt Release @ ab07000

This commit is contained in:
IQ.Lvbs CI [bot]
2026-08-07 23:37:10 -05:00
commit 41f22cf35b
3729 changed files with 778697 additions and 0 deletions

View File

@@ -0,0 +1,13 @@
from tinygrad.runtime.ops_cl import CLDevice, CLProgram, compile_cl
if __name__ == "__main__":
dev = CLDevice()
lib = compile_cl("""
#pragma OPENCL EXTENSION cl_khr_fp16 : enable
__kernel void test(__global half *out, __global half *a, __global half *b) {
int gid = get_global_id(0);
out[gid] = max(a[gid], b[gid]);
}
""")
prg = CLProgram(dev, "test", lib)